metadata(version="0.2.4")

# Originally written by Paul Sokolovsky.

require("ffilib")

module("sqlite3.py")
